pub struct User<'a, P = Utf8PathBuf>(/* private fields */);Implementations
Sourceimpl<'a, P: AsRef<Utf8Path>> User<'a, P>
impl<'a, P: AsRef<Utf8Path>> User<'a, P>
pub fn repository(&self, name: &RepositoryName) -> Repository<'a, Utf8PathBuf>
pub async fn create_repository( &self, name: &RepositoryName, meta: Meta, conf: &RepositoryConfig, ) -> Result<Repository<'a, Utf8PathBuf>, CreateError<Error>>
Methods from Deref<Target = Entity<'a, P>>
Sourcepub fn child(&self, path: impl AsRef<Utf8Path>) -> Entity<'a, Utf8PathBuf>
pub fn child(&self, path: impl AsRef<Utf8Path>) -> Entity<'a, Utf8PathBuf>
Returns a child Entity rooted at path.
Sourcepub async fn get_content(&self) -> Result<impl '_ + AsyncRead, GetError<Error>>
pub async fn get_content(&self) -> Result<impl '_ + AsyncRead, GetError<Error>>
Returns contents of the entity as AsyncRead.
Sourcepub async fn read_content(&self) -> Result<Vec<u8>, GetError<Error>>
pub async fn read_content(&self) -> Result<Vec<u8>, GetError<Error>>
Reads contents of the entity.
Sourcepub async fn get_content_json<T>(&self) -> Result<T, GetError<Error>>where
for<'de> T: Deserialize<'de>,
pub async fn get_content_json<T>(&self) -> Result<T, GetError<Error>>where
for<'de> T: Deserialize<'de>,
Returns the contents of the entity as JSON.
Sourcepub async fn get(&self) -> Result<(Meta, impl '_ + AsyncRead), GetError<Error>>
pub async fn get(&self) -> Result<(Meta, impl '_ + AsyncRead), GetError<Error>>
Returns metadata of the entity and a reader of its contents.
Sourcepub async fn get_to_writer(
&self,
dst: &mut (impl Unpin + AsyncWrite),
) -> Result<Meta, GetToWriterError<Error>>
pub async fn get_to_writer( &self, dst: &mut (impl Unpin + AsyncWrite), ) -> Result<Meta, GetToWriterError<Error>>
Returns metadata of the entity and writes its contents into dst.